# Secursus Integration API

![](https://www.secursus.com/img/logo-h-base.png)

Secursus is the most powerful digital insurance for parcels, covering the most sensitive items and up to €100,000 per parcel.
To integrate the insurance service in your website, we provide this php library that will allow you to automate your insurance orders.

For more information about the product, please visit our website :
https://www.secursus.com/integration/

## Prerequisite

To use the Secursus API, you need to create an account on our platform and activate it.

https://www.secursus.com/integration/registration.php

## Installation

```
pip install -i secursus-api
```

## Usage

```python
from secursus_api import api as secursus_api

# Set your API credentials here
secursus = secursus_api.Api(
    'YOUR_API_ID',
    'YOUR_API_KEY'
)

# And call methods after
response = secursus.retrieve_parcel_order("YOUR_PARCEL_ID")
```


## Documentation

### Get the insurance amount fees

This method is used to calculate the amount of insurance fees.

More details : https://developer.secursus.com/parcels/fees

#### Usage

```python
insurance_amount = secursus.get_insurance_amount(10000)
```

#### Argument

The create parcel order method can receive only one argument, the parcel value. This argument need to be an `integer` and represents the total value of the parcel in euro cents.


### Create parcel order

A parcel object is created and the insurance credentials are returned. Once the object has been created, you have 12 hours if you want to cancel the insurance order.

More details : https://developer.secursus.com/parcels/create

#### Usage
```python
parcel_order = secursus.create_parcel_order(params)
```

#### Data argument

The create parcel order method can receive an `dictionary` who can contains these eight arguments (six are required):

| Entry | Required | Data type | Description |
|-------|----------|-----------|-------------|
| `parcel_value` | Yes | Integer | Total value of the order in euro cents. |
| `first_name` | Yes | String | Customer first name. |
| `last_name` | Yes | String | Customer last name. |
| `email` | Yes | String | Customer email address. |
| `full_address` | Yes | String | Customer full address. |
| `cart_data` | Yes | Json | Details of cart on your website. No specific format is required, this information will be analyzed for any claim. |
| `company` | No | String | Customer company name. |
| `lang` | No | String | Language used for the insurance confirmation email sent to the customer. Two possible values: "fr" or "en". Default value: "en". |


### Retrieve a parcel order

This method is used to get the insurance credentials and parcel informations.

#### Usage
```python
parcel_order = secursus.retrieve_parcel_order(id_parcel)
```

#### Argument

The retrieve parcel order method can receive only one argument, the parcel id. This argument need to be a `string` and is the insurance id generated by the createParcelOrder method.


### Retrieve a history parcel report

This method is used to get the list of all parcels of the account.

#### Usage
```python
parcel_order = secursus.retrieve_history_report(id_parcel)
```


### Retrieve a current parcel report

This method is used to get the list of all parcels to due during the current month.

#### Usage
```python
parcel_order = secursus.retrieve_current_report(id_parcel)
```


### Cancel a parcel order

This method is used to cancel an insurance order that you previously sent.

Note: Once the insurance request has been created, you have 12 hours if you want to cancel the insurance order. After this period, the insurance order is considered as confirmed and can't be canceled. The insurance fees are then payable.

More details : https://developer.secursus.com/parcels/cancel

#### Usage
```python
parcel_order = secursus.cancel_parcel_order(id_parcel)
```

#### Argument

The retrieve parcel order method can receive only one argument, the parcel id. This argument need to be a `string` and is the insurance id generated by the createParcelOrder method.